from os import *

# Console
def couleur(rouge: int, vert: int, bleu: int, texte: str):
    return "\033[38;2;{};{};{}m{}".format(rouge, vert, bleu, texte)
def txt(nombre: str):
    return int(nombre)
def num(nombre: int):
    return str(nombre)
def afficher(texte: str):
    return print(texte + couleur(203, 203, 203, ''))
def demander(question: str):
    return input('{}\n'.format(question) + couleur(203, 203, 203, ''))
def erreur(erreur: str):
    return print(couleur(255, 0, 0, 'ERREUR: {}'.format(erreur)) + couleur(203, 203, 203, ''))
def attention(texte: str):
    return print(couleur(235, 192, 52, 'ATTENTION: {}'.format(texte)) + couleur(203, 203, 203, ''))
def succes(texte: str):
    return print(couleur(45, 166, 49, 'SUCCÈS: {}'.format(texte)) + couleur(203, 203, 203, ''))
def conseil(texte: str):
    return print(couleur(80, 140, 212, 'CONSEIL: {}'.format(texte)) + couleur(203, 203, 203, ''))
def cls():
    if name == "nt":
        system("cls")
    else:
        system("clear")

# Fichier
def ouvrir(fichier: str):
    return open(file=fichier)

# Vrai/Faux
def Vrai():
    return True
def Faux():
    return False


from setuptools import find_packages, setup

setup(
    name='pyfrench',
    packages=find_packages(),
    version='0.1.4',
    description='Une librairie qui traduit python en français',
    long_description='Une librairie python de toute versions qui traduit ajoute les même fonctionnalités python sur le module en français.',
    author='Artic#6377',
    license='MIT',
    install_requires=[],
    setup_requires=['pytest-runner'], 
    tests_require=['pytest'], 
    test_suite='tests',
    author_email="artic.admisoffi@gmail.com"
)